@@ -1,7 +1,6 @@
 package POE::Component::Metabase::Relay::Server;
-$POE::Component::Metabase::Relay::Server::VERSION = '0.34';
 # ABSTRACT: A Metabase relay server component
-
+$POE::Component::Metabase::Relay::Server::VERSION = '0.36';
 use strict;
 use warnings;
 use CPAN::Testers::Report;
@@ -240,9 +239,20 @@ event 'shutdown' => sub {
 
 event 'relayd_registered' => sub {
   my ($kernel,$self,$relayd) = @_[KERNEL,OBJECT,ARG0];
-  my ($port, $addr) = Socket::sockaddr_in($relayd->getsockname);
-  warn "Listening on '", join(q{:} => scalar gethostbyaddr($addr, Socket::AF_INET), $port), "'\n"
-    if $self->debug;
+  my ($port, $addr) = Socket::unpack_sockaddr_in($relayd->getsockname);
+
+  if ($self->debug) {
+      my $hostname = scalar(gethostbyaddr($addr, Socket::AF_INET));
+
+      if (defined($hostname)) {
+          warn "Listening on '", join(q{:} => $hostname, $port), "'\n";
+      } else {
+          my $dotted_num = Socket::inet_ntoa($addr);
+          warn "Listening on '", join(q{:} => $dotted_num, $port), "'\n";
+      }
+
+  }
+
   $self->_set_port( $relayd->port );
   return;
 };
@@ -353,7 +363,7 @@ POE::Component::Metabase::Relay::Server - A Metabase relay server component
 
 =head1 VERSION
 
-version 0.34
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -383,6 +393,14 @@ L<POE::Component::Client::HTTP> is used to submit reports usually, but if versio
 L<POE::Component::Curl::Multi> is found to be installed, this will be used in preference. You can
 disable this usage using the C<no_curl> option to C<spawn>.
 
+=head1 NAME
+
+POE::Component::Metabase::Relay::Server - A Metabase relay server component
+
+=head1 VERSION
+
+version 0.34
+
 =for Pod::Coverage START
 
 =head1 CONSTRUCTOR
@@ -450,4 +468,15 @@ This software is copyright (c) 2014 by Chris Williams.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
